==> xmonad-contrib-0.16-39-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xmonad-contrib
version:              0.16
visibility:           public
id:                   xmonad-contrib-0.16-BFfiDzomG0d1dtDWVrjQw7
key:                  xmonad-contrib-0.16-BFfiDzomG0d1dtDWVrjQw7
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:               Spencer Janssen & others
homepage:             http://xmonad.org/
synopsis:             Third party extensions for xmonad
description:
    Third party tiling algorithms, configurations and scripts to xmonad,
    a tiling window manager for X.

    For an introduction to building, configuring and using xmonad
    extensions, see "XMonad.Doc". In particular:

    "XMonad.Doc.Configuring", a guide to configuring xmonad

    "XMonad.Doc.Extending", using the contributed extensions library

    "XMonad.Doc.Developing", introduction to xmonad internals and writing
    your own extensions.

category:             System
abi:                  a8535366ffc45120ad2f8f2ed8ce2a27
exposed:              True
exposed-modules:
    XMonad.Actions.AfterDrag XMonad.Actions.BluetileCommands
    XMonad.Actions.Commands XMonad.Actions.ConstrainedResize
    XMonad.Actions.CopyWindow XMonad.Actions.CycleRecentWS
    XMonad.Actions.CycleSelectedLayouts XMonad.Actions.CycleWS
    XMonad.Actions.CycleWindows XMonad.Actions.CycleWorkspaceByScreen
    XMonad.Actions.DeManage XMonad.Actions.DwmPromote
    XMonad.Actions.DynamicProjects
    XMonad.Actions.DynamicWorkspaceGroups
    XMonad.Actions.DynamicWorkspaceOrder
    XMonad.Actions.DynamicWorkspaces XMonad.Actions.FindEmptyWorkspace
    XMonad.Actions.FlexibleManipulate XMonad.Actions.FlexibleResize
    XMonad.Actions.FloatKeys XMonad.Actions.FloatSnap
    XMonad.Actions.FocusNth XMonad.Actions.GridSelect
    XMonad.Actions.GroupNavigation XMonad.Actions.KeyRemap
    XMonad.Actions.Launcher XMonad.Actions.LinkWorkspaces
    XMonad.Actions.MessageFeedback XMonad.Actions.Minimize
    XMonad.Actions.MouseGestures XMonad.Actions.MouseResize
    XMonad.Actions.Navigation2D XMonad.Actions.NoBorders
    XMonad.Actions.OnScreen XMonad.Actions.PerWorkspaceKeys
    XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
    XMonad.Actions.Promote XMonad.Actions.RandomBackground
    XMonad.Actions.RotSlaves XMonad.Actions.Search
    XMonad.Actions.ShowText XMonad.Actions.SimpleDate
    XMonad.Actions.SinkAll XMonad.Actions.SpawnOn XMonad.Actions.Submap
    XMonad.Actions.SwapPromote XMonad.Actions.SwapWorkspaces
    XMonad.Actions.TagWindows XMonad.Actions.TopicSpace
    XMonad.Actions.TreeSelect XMonad.Actions.UpdateFocus
    XMonad.Actions.UpdatePointer XMonad.Actions.Warp
    XMonad.Actions.WindowBringer XMonad.Actions.WindowGo
    XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
    XMonad.Actions.WithAll XMonad.Actions.Workscreen
    XMonad.Actions.WorkspaceCursors XMonad.Actions.WorkspaceNames
    XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Bepo
    XMonad.Config.Bluetile XMonad.Config.Desktop XMonad.Config.Dmwit
    XMonad.Config.Droundy XMonad.Config.Gnome XMonad.Config.Kde
    XMonad.Config.Mate XMonad.Config.Prime XMonad.Config.Sjanssen
    XMonad.Config.Xfce XMonad.Doc XMonad.Doc.Configuring
    XMonad.Doc.Developing XMonad.Doc.Extending
    XMonad.Hooks.CurrentWorkspaceOnTop XMonad.Hooks.DebugEvents
    XMonad.Hooks.DebugKeyEvents XMonad.Hooks.DebugStack
    XMonad.Hooks.DynamicBars XMonad.Hooks.DynamicHooks
    XMonad.Hooks.DynamicLog XMonad.Hooks.DynamicProperty
    XMonad.Hooks.EwmhDesktops XMonad.Hooks.FadeInactive
    XMonad.Hooks.FadeWindows XMonad.Hooks.FloatNext
    XMonad.Hooks.ICCCMFocus XMonad.Hooks.InsertPosition
    XMonad.Hooks.ManageDebug XMonad.Hooks.ManageDocks
    XMonad.Hooks.ManageHelpers XMonad.Hooks.Minimize XMonad.Hooks.Place
    XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RefocusLast
    XMonad.Hooks.RestoreMinimized XMonad.Hooks.ScreenCorners
    XMonad.Hooks.Script XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
    XMonad.Hooks.ToggleHook XMonad.Hooks.UrgencyHook
    XMonad.Hooks.WallpaperSetter XMonad.Hooks.WorkspaceByPos
    XMonad.Hooks.WorkspaceHistory XMonad.Hooks.XPropManage
    XMonad.Layout.Accordion XMonad.Layout.AutoMaster
    XMonad.Layout.AvoidFloats XMonad.Layout.BinaryColumn
    XMonad.Layout.BinarySpacePartition XMonad.Layout.BorderResize
    XMonad.Layout.BoringWindows XMonad.Layout.ButtonDecoration
    XMonad.Layout.CenteredMaster XMonad.Layout.Circle
    XMonad.Layout.Column XMonad.Layout.Combo XMonad.Layout.ComboP
    XMonad.Layout.Cross XMonad.Layout.Decoration
    XMonad.Layout.DecorationAddons XMonad.Layout.DecorationMadness
    XMonad.Layout.Dishes XMonad.Layout.DragPane
    XMonad.Layout.DraggingVisualizer XMonad.Layout.Drawer
    XMonad.Layout.Dwindle XMonad.Layout.DwmStyle
    XMonad.Layout.FixedColumn XMonad.Layout.Fullscreen
    XMonad.Layout.Gaps XMonad.Layout.Grid XMonad.Layout.GridVariants
    XMonad.Layout.Groups XMonad.Layout.Groups.Examples
    XMonad.Layout.Groups.Helpers XMonad.Layout.Groups.Wmii
    XMonad.Layout.Hidden XMonad.Layout.HintedGrid
    XMonad.Layout.HintedTile XMonad.Layout.IM XMonad.Layout.IfMax
    XMonad.Layout.ImageButtonDecoration
    XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
    XMonad.Layout.LayoutBuilderP XMonad.Layout.LayoutCombinators
    XMonad.Layout.LayoutHints XMonad.Layout.LayoutModifier
    XMonad.Layout.LayoutScreens XMonad.Layout.LimitWindows
    XMonad.Layout.MagicFocus XMonad.Layout.Magnifier
    XMonad.Layout.Master XMonad.Layout.Maximize
    XMonad.Layout.MessageControl XMonad.Layout.Minimize
    XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
    XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
    XMonad.Layout.MultiDishes XMonad.Layout.MultiToggle
    XMonad.Layout.MultiToggle.Instances
    XMonad.Layout.MultiToggle.TabBarDecoration XMonad.Layout.Named
    XMonad.Layout.NoBorders XMonad.Layout.NoFrillsDecoration
    XMonad.Layout.OnHost XMonad.Layout.OneBig XMonad.Layout.PerScreen
    XMonad.Layout.PerWorkspace XMonad.Layout.PositionStoreFloat
    XMonad.Layout.Reflect XMonad.Layout.Renamed
    XMonad.Layout.ResizableTile XMonad.Layout.ResizeScreen
    XMonad.Layout.Roledex XMonad.Layout.ShowWName
    XMonad.Layout.SimpleDecoration XMonad.Layout.SimpleFloat
    XMonad.Layout.Simplest XMonad.Layout.SimplestFloat
    XMonad.Layout.SortedLayout XMonad.Layout.Spacing
    XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.StackTile
    XMonad.Layout.StateFull XMonad.Layout.Stoppable
    XMonad.Layout.SubLayouts XMonad.Layout.TabBarDecoration
    XMonad.Layout.Tabbed XMonad.Layout.ThreeColumns
    XMonad.Layout.ToggleLayouts XMonad.Layout.TrackFloating
    XMonad.Layout.TwoPane XMonad.Layout.TwoPanePersistent
    XMonad.Layout.WindowArranger XMonad.Layout.WindowNavigation
    XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
    XMonad.Layout.ZoomRow XMonad.Prompt XMonad.Prompt.AppLauncher
    XMonad.Prompt.AppendFile XMonad.Prompt.ConfirmPrompt
    XMonad.Prompt.DirExec XMonad.Prompt.Directory XMonad.Prompt.Email
    XMonad.Prompt.FuzzyMatch XMonad.Prompt.Input XMonad.Prompt.Layout
    XMonad.Prompt.Man XMonad.Prompt.Pass XMonad.Prompt.RunOrRaise
    XMonad.Prompt.Shell XMonad.Prompt.Ssh XMonad.Prompt.Theme
    XMonad.Prompt.Unicode XMonad.Prompt.Window XMonad.Prompt.Workspace
    XMonad.Prompt.XMonad XMonad.Util.Cursor XMonad.Util.CustomKeys
    XMonad.Util.DebugWindow XMonad.Util.Dmenu XMonad.Util.Dzen
    XMonad.Util.EZConfig XMonad.Util.ExclusiveScratchpads
    XMonad.Util.ExtensibleState XMonad.Util.Font XMonad.Util.Image
    XMonad.Util.Invisible XMonad.Util.Loggers
    XMonad.Util.Loggers.NamedScratchpad XMonad.Util.Minimize
    XMonad.Util.NamedActions XMonad.Util.NamedScratchpad
    XMonad.Util.NamedWindows XMonad.Util.NoTaskbar XMonad.Util.Paste
    XMonad.Util.PositionStore XMonad.Util.PureX XMonad.Util.Rectangle
    XMonad.Util.RemoteWindows XMonad.Util.Replace XMonad.Util.Run
    XMonad.Util.Scratchpad XMonad.Util.SessionStart
    XMonad.Util.SpawnNamedPipe XMonad.Util.SpawnOnce XMonad.Util.Stack
    XMonad.Util.StringProp XMonad.Util.Themes XMonad.Util.Timer
    XMonad.Util.TreeZipper XMonad.Util.Types XMonad.Util.Ungrab
    XMonad.Util.WindowProperties XMonad.Util.WindowState
    XMonad.Util.WorkspaceCompare XMonad.Util.XSelection
    XMonad.Util.XUtils

import-dirs:          /usr/lib/ghc-8.10.2/site-local/xmonad-contrib-0.16
library-dirs:         /usr/lib/ghc-8.10.2/site-local/xmonad-contrib-0.16
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.10.2
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/xmonad-contrib-0.16
hs-libraries:         HSxmonad-contrib-0.16-BFfiDzomG0d1dtDWVrjQw7
depends:
    X11-1.9.2-9XlOM8qfaphHQHcyPJLt24
    X11-xft-0.3.1-7aHTLnsrjqkG5MKsURXW4H base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1 directory-1.3.6.0
    extensible-exceptions-0.1.1.4-DY91N4N9LFmCiQpNXwJXMT
    filepath-1.4.2.1 mtl-2.2.2 old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    old-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK process-1.6.9.0
    random-1.2.0-6c4YcHIwqiT3PlUDhzT021 unix-2.7.2.2
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R
    xmonad-0.15-GFXaeWoa5isBQtonTp8BV2

haddock-interfaces:   /usr/share/doc/xmonad-contrib/html/xmonad-contrib.haddock
haddock-html:         /usr/share/doc/xmonad-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-contrib-0.16-41-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xmonad-contrib
version:              0.16
visibility:           public
id:                   xmonad-contrib-0.16-ABdMVv63ZmOKF2f8xX1JBS
key:                  xmonad-contrib-0.16-ABdMVv63ZmOKF2f8xX1JBS
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:               Spencer Janssen & others
homepage:             http://xmonad.org/
synopsis:             Third party extensions for xmonad
description:
    Third party tiling algorithms, configurations and scripts to xmonad,
    a tiling window manager for X.

    For an introduction to building, configuring and using xmonad
    extensions, see "XMonad.Doc". In particular:

    "XMonad.Doc.Configuring", a guide to configuring xmonad

    "XMonad.Doc.Extending", using the contributed extensions library

    "XMonad.Doc.Developing", introduction to xmonad internals and writing
    your own extensions.

category:             System
abi:                  3c40d030413fae3986e26dae9ca25e37
exposed:              True
exposed-modules:
    XMonad.Actions.AfterDrag XMonad.Actions.BluetileCommands
    XMonad.Actions.Commands XMonad.Actions.ConstrainedResize
    XMonad.Actions.CopyWindow XMonad.Actions.CycleRecentWS
    XMonad.Actions.CycleSelectedLayouts XMonad.Actions.CycleWS
    XMonad.Actions.CycleWindows XMonad.Actions.CycleWorkspaceByScreen
    XMonad.Actions.DeManage XMonad.Actions.DwmPromote
    XMonad.Actions.DynamicProjects
    XMonad.Actions.DynamicWorkspaceGroups
    XMonad.Actions.DynamicWorkspaceOrder
    XMonad.Actions.DynamicWorkspaces XMonad.Actions.FindEmptyWorkspace
    XMonad.Actions.FlexibleManipulate XMonad.Actions.FlexibleResize
    XMonad.Actions.FloatKeys XMonad.Actions.FloatSnap
    XMonad.Actions.FocusNth XMonad.Actions.GridSelect
    XMonad.Actions.GroupNavigation XMonad.Actions.KeyRemap
    XMonad.Actions.Launcher XMonad.Actions.LinkWorkspaces
    XMonad.Actions.MessageFeedback XMonad.Actions.Minimize
    XMonad.Actions.MouseGestures XMonad.Actions.MouseResize
    XMonad.Actions.Navigation2D XMonad.Actions.NoBorders
    XMonad.Actions.OnScreen XMonad.Actions.PerWorkspaceKeys
    XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
    XMonad.Actions.Promote XMonad.Actions.RandomBackground
    XMonad.Actions.RotSlaves XMonad.Actions.Search
    XMonad.Actions.ShowText XMonad.Actions.SimpleDate
    XMonad.Actions.SinkAll XMonad.Actions.SpawnOn XMonad.Actions.Submap
    XMonad.Actions.SwapPromote XMonad.Actions.SwapWorkspaces
    XMonad.Actions.TagWindows XMonad.Actions.TopicSpace
    XMonad.Actions.TreeSelect XMonad.Actions.UpdateFocus
    XMonad.Actions.UpdatePointer XMonad.Actions.Warp
    XMonad.Actions.WindowBringer XMonad.Actions.WindowGo
    XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
    XMonad.Actions.WithAll XMonad.Actions.Workscreen
    XMonad.Actions.WorkspaceCursors XMonad.Actions.WorkspaceNames
    XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Bepo
    XMonad.Config.Bluetile XMonad.Config.Desktop XMonad.Config.Dmwit
    XMonad.Config.Droundy XMonad.Config.Gnome XMonad.Config.Kde
    XMonad.Config.Mate XMonad.Config.Prime XMonad.Config.Sjanssen
    XMonad.Config.Xfce XMonad.Doc XMonad.Doc.Configuring
    XMonad.Doc.Developing XMonad.Doc.Extending
    XMonad.Hooks.CurrentWorkspaceOnTop XMonad.Hooks.DebugEvents
    XMonad.Hooks.DebugKeyEvents XMonad.Hooks.DebugStack
    XMonad.Hooks.DynamicBars XMonad.Hooks.DynamicHooks
    XMonad.Hooks.DynamicLog XMonad.Hooks.DynamicProperty
    XMonad.Hooks.EwmhDesktops XMonad.Hooks.FadeInactive
    XMonad.Hooks.FadeWindows XMonad.Hooks.FloatNext
    XMonad.Hooks.ICCCMFocus XMonad.Hooks.InsertPosition
    XMonad.Hooks.ManageDebug XMonad.Hooks.ManageDocks
    XMonad.Hooks.ManageHelpers XMonad.Hooks.Minimize XMonad.Hooks.Place
    XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RefocusLast
    XMonad.Hooks.RestoreMinimized XMonad.Hooks.ScreenCorners
    XMonad.Hooks.Script XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
    XMonad.Hooks.ToggleHook XMonad.Hooks.UrgencyHook
    XMonad.Hooks.WallpaperSetter XMonad.Hooks.WorkspaceByPos
    XMonad.Hooks.WorkspaceHistory XMonad.Hooks.XPropManage
    XMonad.Layout.Accordion XMonad.Layout.AutoMaster
    XMonad.Layout.AvoidFloats XMonad.Layout.BinaryColumn
    XMonad.Layout.BinarySpacePartition XMonad.Layout.BorderResize
    XMonad.Layout.BoringWindows XMonad.Layout.ButtonDecoration
    XMonad.Layout.CenteredMaster XMonad.Layout.Circle
    XMonad.Layout.Column XMonad.Layout.Combo XMonad.Layout.ComboP
    XMonad.Layout.Cross XMonad.Layout.Decoration
    XMonad.Layout.DecorationAddons XMonad.Layout.DecorationMadness
    XMonad.Layout.Dishes XMonad.Layout.DragPane
    XMonad.Layout.DraggingVisualizer XMonad.Layout.Drawer
    XMonad.Layout.Dwindle XMonad.Layout.DwmStyle
    XMonad.Layout.FixedColumn XMonad.Layout.Fullscreen
    XMonad.Layout.Gaps XMonad.Layout.Grid XMonad.Layout.GridVariants
    XMonad.Layout.Groups XMonad.Layout.Groups.Examples
    XMonad.Layout.Groups.Helpers XMonad.Layout.Groups.Wmii
    XMonad.Layout.Hidden XMonad.Layout.HintedGrid
    XMonad.Layout.HintedTile XMonad.Layout.IM XMonad.Layout.IfMax
    XMonad.Layout.ImageButtonDecoration
    XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
    XMonad.Layout.LayoutBuilderP XMonad.Layout.LayoutCombinators
    XMonad.Layout.LayoutHints XMonad.Layout.LayoutModifier
    XMonad.Layout.LayoutScreens XMonad.Layout.LimitWindows
    XMonad.Layout.MagicFocus XMonad.Layout.Magnifier
    XMonad.Layout.Master XMonad.Layout.Maximize
    XMonad.Layout.MessageControl XMonad.Layout.Minimize
    XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
    XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
    XMonad.Layout.MultiDishes XMonad.Layout.MultiToggle
    XMonad.Layout.MultiToggle.Instances
    XMonad.Layout.MultiToggle.TabBarDecoration XMonad.Layout.Named
    XMonad.Layout.NoBorders XMonad.Layout.NoFrillsDecoration
    XMonad.Layout.OnHost XMonad.Layout.OneBig XMonad.Layout.PerScreen
    XMonad.Layout.PerWorkspace XMonad.Layout.PositionStoreFloat
    XMonad.Layout.Reflect XMonad.Layout.Renamed
    XMonad.Layout.ResizableTile XMonad.Layout.ResizeScreen
    XMonad.Layout.Roledex XMonad.Layout.ShowWName
    XMonad.Layout.SimpleDecoration XMonad.Layout.SimpleFloat
    XMonad.Layout.Simplest XMonad.Layout.SimplestFloat
    XMonad.Layout.SortedLayout XMonad.Layout.Spacing
    XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.StackTile
    XMonad.Layout.StateFull XMonad.Layout.Stoppable
    XMonad.Layout.SubLayouts XMonad.Layout.TabBarDecoration
    XMonad.Layout.Tabbed XMonad.Layout.ThreeColumns
    XMonad.Layout.ToggleLayouts XMonad.Layout.TrackFloating
    XMonad.Layout.TwoPane XMonad.Layout.TwoPanePersistent
    XMonad.Layout.WindowArranger XMonad.Layout.WindowNavigation
    XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
    XMonad.Layout.ZoomRow XMonad.Prompt XMonad.Prompt.AppLauncher
    XMonad.Prompt.AppendFile XMonad.Prompt.ConfirmPrompt
    XMonad.Prompt.DirExec XMonad.Prompt.Directory XMonad.Prompt.Email
    XMonad.Prompt.FuzzyMatch XMonad.Prompt.Input XMonad.Prompt.Layout
    XMonad.Prompt.Man XMonad.Prompt.Pass XMonad.Prompt.RunOrRaise
    XMonad.Prompt.Shell XMonad.Prompt.Ssh XMonad.Prompt.Theme
    XMonad.Prompt.Unicode XMonad.Prompt.Window XMonad.Prompt.Workspace
    XMonad.Prompt.XMonad XMonad.Util.Cursor XMonad.Util.CustomKeys
    XMonad.Util.DebugWindow XMonad.Util.Dmenu XMonad.Util.Dzen
    XMonad.Util.EZConfig XMonad.Util.ExclusiveScratchpads
    XMonad.Util.ExtensibleState XMonad.Util.Font XMonad.Util.Image
    XMonad.Util.Invisible XMonad.Util.Loggers
    XMonad.Util.Loggers.NamedScratchpad XMonad.Util.Minimize
    XMonad.Util.NamedActions XMonad.Util.NamedScratchpad
    XMonad.Util.NamedWindows XMonad.Util.NoTaskbar XMonad.Util.Paste
    XMonad.Util.PositionStore XMonad.Util.PureX XMonad.Util.Rectangle
    XMonad.Util.RemoteWindows XMonad.Util.Replace XMonad.Util.Run
    XMonad.Util.Scratchpad XMonad.Util.SessionStart
    XMonad.Util.SpawnNamedPipe XMonad.Util.SpawnOnce XMonad.Util.Stack
    XMonad.Util.StringProp XMonad.Util.Themes XMonad.Util.Timer
    XMonad.Util.TreeZipper XMonad.Util.Types XMonad.Util.Ungrab
    XMonad.Util.WindowProperties XMonad.Util.WindowState
    XMonad.Util.WorkspaceCompare XMonad.Util.XSelection
    XMonad.Util.XUtils

import-dirs:          /usr/lib/ghc-8.10.2/site-local/xmonad-contrib-0.16
library-dirs:         /usr/lib/ghc-8.10.2/site-local/xmonad-contrib-0.16
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.10.2
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/xmonad-contrib-0.16
hs-libraries:         HSxmonad-contrib-0.16-ABdMVv63ZmOKF2f8xX1JBS
depends:
    X11-1.9.2-Fs21r2vSEckL4C8dsIzhvD
    X11-xft-0.3.1-3WDgIxjm8PS8AobOtH3UZU base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1 directory-1.3.6.0
    extensible-exceptions-0.1.1.4-DY91N4N9LFmCiQpNXwJXMT
    filepath-1.4.2.1 mtl-2.2.2 old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    old-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK process-1.6.9.0
    random-1.2.0-ArkgnsvKZOJCInyIxwD8ha unix-2.7.2.2
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R
    xmonad-0.15-5t6yGu5F7iQ6GmmQtvGmiB

haddock-interfaces:   /usr/share/doc/xmonad-contrib/html/xmonad-contrib.haddock
haddock-html:         /usr/share/doc/xmonad-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
